-- Oracle dump 1.0
--
-- Host: localhost    Database: organization
-- ------------------------------------------------------
-- Server version 10.2.0.1

--
-- LiquiBase
--

CREATE TABLE DATABASECHANGELOG (
  ID varchar2(63) NOT NULL,
  AUTHOR varchar2(63) NOT NULL,
  FILENAME varchar2(200) NOT NULL,
  DATEEXECUTED timestamp NOT NULL,
  MD5SUM varchar2(32) default NULL,
  DESCRIPTION varchar2(255) default NULL,
  COMMENTS varchar2(255) default NULL,
  TAG varchar2(255) default NULL,
  LIQUIBASE varchar2(10) default NULL,
  CONSTRAINT pk_DATABASECHANGELOG PRIMARY KEY (ID,AUTHOR,FILENAME)
);

CREATE TABLE DATABASECHANGELOGLOCK (
  ID number(11,0) NOT NULL,
  LOCKED number(1,0) NOT NULL,
  LOCKGRANTED timestamp default NULL,
  LOCKEDBY varchar2(255) default NULL,
  CONSTRAINT pk_DATABASECHANGELOGLOCK PRIMARY KEY (ID)
);

--*******************************************************
-- System module
--*******************************************************
--
-- Table structure for table 'Users'
--

CREATE TABLE Users (
  ID number(19,0) NOT NULL,
  UserID varchar2(40) NOT NULL,
  Name varchar2(120),
  EMail varchar2(80),
  GSM varchar2(40),
  Password varchar2(40),
  CONSTRAINT pk_users PRIMARY KEY (ID)
);

--
-- Table structure for table  'UserRight' 
--

CREATE TABLE UserRight(
  userId number(19,0) NOT NULL, 
  accessZone varchar2(40) NOT NULL, 
  CONSTRAINT pk_user_right PRIMARY KEY (userId, accessZone)
);

--*********************
-- End of System module
--********************* 
--******************************************************* 
-- Visual module
--******************************************************* 

--
-- Table structure for table 'Theme'
--

CREATE TABLE Theme (
  id number(19,0) NOT NULL,
  name varchar2(255) NOT NULL,
  priceGroup number(5,0),
  CONSTRAINT pk_theme PRIMARY KEY (id)
);

--
-- Table structure for table 'Page'
--

CREATE TABLE Page (
  id number(19,0) NOT NULL,
  themeId number(19,0) NOT NULL,
  typeId number(19,0) NOT NULL,
  name varchar2(255),
  content clob,
  CONSTRAINT pk_page PRIMARY KEY (id)
);

--
-- Table structure for table  'Elements' 
--

CREATE TABLE Elements (
  ID number(19,0) NOT NULL,
  Position number(10,0) DEFAULT '0' NOT NULL,
  TypeID number(19,0),
  Html clob,
  Style clob,
  Structure clob,
  Text clob,
  Pictures clob,
  CustomerData clob,
  pageId number(19,0) NOT NULL,
  Name varchar2(255),
  CheckboxAnswers clob,
  CONSTRAINT pk_elements PRIMARY KEY (ID)
);

--
-- Table structure for table 'ProductListTemplates'
--

CREATE TABLE ProductListTemplates (
  ElementID number(19,0) NOT NULL,
  StartHTML clob,
  ProductHTML clob,
  EndHTML clob,
  GroupingHTML clob,
  GroupSize number(10,0) DEFAULT '1' NOT NULL,
  ProductPageLinkText varchar2(200),
  AddButtonURL varchar2(200),
  QuantityFieldSize number(10,0)  DEFAULT '5' NOT NULL,
  ProductPromotionGroupID number(19,0),
  NameMaxLength number(10,0) DEFAULT '0' NOT NULL,
  NameLink number(5,0) DEFAULT '0' NOT NULL,
  UsePaging number(10,0) DEFAULT '0' NOT NULL,
  ProductsPerPage number(5,0) DEFAULT '10' NOT NULL,
  NextPageLinkText varchar2(255),
  PrevPageLinkText varchar2(255),
  SaveButton varchar2(255),
  RestoreButton varchar2(255),
  UpdateButton varchar2(255),
  DeleteItemButton varchar2(255),
  DeleteAllButton varchar2(255),
  OrderStatusSelector number(19,0),
  PictureLink number(5,0) DEFAULT '0' NOT NULL,
  IdLink number(5,0) DEFAULT '0' NOT NULL,
  ErrorHTML clob,
  PromotionCriteria number(5,0) DEFAULT '1' NOT NULL,
  SearchQuery clob,
  DescriptionMaxLength number(10,0) DEFAULT '0' NOT NULL,
  AddAllButton varchar2(255),
  OrderButton varchar2(255),
  AddItemButton varchar2(255),
  UpdateItemButton varchar2(255),
  AddToWishlistButton varchar2(255),
  AddAllWishlistButton varchar2(255),
  AddWishlistButtonURL varchar2(255),
  CONSTRAINT pk_product_list_template PRIMARY KEY (ElementID)
);

--********************* 
-- End of Visual module
--********************* 
--******************************************************* 
-- Question module
--******************************************************* 

CREATE TABLE QuestionCollection (
	id number(19,0) NOT NULL,
	name varchar2(64) NOT NULL,
	CONSTRAINT pk_question_collection PRIMARY KEY (id)
);

CREATE TABLE Question (
	id number(19,0) NOT NULL,
	clientMode varchar2(16) NOT NULL,
	collectionId number(19,0),
	customerEnabled number(3,0) NOT NULL,
	orderEnabled number(3,0) NOT NULL,
	position number(10,0),
	required number(3,0) NOT NULL,
	discriminatorType number(19,0) NOT NULL,
	usedInMatchingEnabled number(3,0) NOT NULL,
	typeId number(19,0) NOT NULL,
	CONSTRAINT pk_question PRIMARY KEY (id)
);

CREATE TABLE QuestionValidator (
	id number(19,0) NOT NULL,
	discriminator varchar2(64) NOT NULL,
	enabled number(3,0) NOT NULL,
	maxLength number(10,0),
	minLength number(10,0),
	questionId number(19,0) NOT NULL,
	whitelist clob,
	CONSTRAINT pk_question_validator PRIMARY KEY (id)
);

CREATE TABLE QuestionVersion (
	id number(19,0) NOT NULL,
	label clob NOT NULL,
	position number(10,0) NOT NULL,
	questionId number(19,0) NOT NULL,
	CONSTRAINT pk_question_version PRIMARY KEY (id)
);

CREATE TABLE QuestionSetting (
	id number(19,0) NOT NULL,
	name varchar2(64) NOT NULL,
	questionVersionId number(19,0) NOT NULL,
	value clob,
	CONSTRAINT pk_question_setting PRIMARY KEY (id)
);

CREATE TABLE Answer (
	id number(19,0) NOT NULL,
	value clob,
	customerId number(19,0),
	orderId number(19,0),
	position number(10,0) NOT NULL,
	questionId number(19,0),
	questionVersionId number(19,0),
	typeId number(19,0) NOT NULL,
	CONSTRAINT pk_answer PRIMARY KEY (id)
);

--*********************** 
-- End of Question module
--*********************** 
--************************************************************ 
-- Customer module
-- Dependencies: Question module, System module, Visual module
--************************************************************ 

CREATE TABLE CustomerGroup (
	id number(19,0) NOT NULL,
	name varchar2(255) NOT NULL,
	priceGroup number(10,0),
	themeId number(19,0),
	CONSTRAINT pk_customer_group PRIMARY KEY (id)
);

CREATE TABLE Customer (
	id number(19,0) NOT NULL,
	averageProducts decimal(12, 2) NOT NULL,
	averageSum decimal(12, 2) NOT NULL,
	contactPersonId number(19,0),
	created timestamp NOT NULL,
	customerNumber varchar2(40) NOT NULL,
	lastVisit timestamp,
	login varchar2(100),
	password varchar2(100),
	primaryGroupId number(19,0),
	timesVisited number(10,0) NOT NULL,
	totalSum decimal(12, 2) NOT NULL,
	customerModified timestamp,
	adminModified timestamp,
	adminId number(19,0),
	CONSTRAINT pk_customer PRIMARY KEY (id)
);

CREATE TABLE CustomerCustomerGroup (
	customerId number(19,0) NOT NULL,
	groupId number(19,0) NOT NULL,
	CONSTRAINT pk_c_c_group PRIMARY KEY (customerId, groupId)
);

CREATE TABLE CustomerComment (
	id number(19,0) NOT NULL,
	customerComment clob NOT NULL,
	created date NOT NULL,
	creatorId number(19,0) NOT NULL,
	customerId number(19,0) NOT NULL,
	CONSTRAINT pk_customer_comment PRIMARY KEY (id)
);

CREATE TABLE Wishlist (
	id number(19,0) NOT NULL,
	customerId number(19,0) NOT NULL,
	name varchar2(50) NOT NULL,
	CONSTRAINT pk_wishlist PRIMARY KEY (id)
);

CREATE TABLE WishlistItem (
	id number(19,0) NOT NULL,
	wishlistId number(19,0) NOT NULL,
	productItemCode varchar2(255) NOT NULL,
	quantity number(10,0) NOT NULL,
	choices clob,
	CONSTRAINT pk_wishlist_item PRIMARY KEY (id)
);

--***********************
-- End of Customer module
--*********************** 
--************************************
-- Product module (VAT-related tables)
--************************************

CREATE TABLE VatRegion (
	id number(19,0) NOT NULL,
	countryCodes clob,
	name varchar2(100) NOT NULL,
	CONSTRAINT pk_vat_region PRIMARY KEY (id)
);

CREATE TABLE VatCategory (
	id number(19,0) NOT NULL,
	defaultRegionId number(19,0) NOT NULL,
	name varchar2(100) NOT NULL,
	CONSTRAINT pk_vat_category PRIMARY KEY (id)
);

CREATE TABLE Vat (
	id number(19,0) NOT NULL,
	rate decimal(12, 2) NOT NULL,
	vatCategoryId number(19,0),
	vatRegionId number(19,0),
	CONSTRAINT pk_vat PRIMARY KEY (id)
);

--**********************
-- End of Product module
--**********************

--
-- Table structure for table  'Basket' 
--

CREATE TABLE Basket (
  	id number(19,0) NOT NULL,
  	itemCode varchar2(255),
  	productId number(19,0) DEFAULT NULL,
  	productName varchar2(4000),
  	quantity number(10,0) DEFAULT NULL,
  	price decimal(12,2) DEFAULT NULL,
  	weight decimal(12, 2) DEFAULT NULL,
  	vat decimal(12, 2) DEFAULT NULL,
  	total decimal(12, 2) DEFAULT NULL,
  	totalweight decimal(12, 2) DEFAULT NULL,
  	sessionId varchar2(64),
  	orderId number(19,0) DEFAULT NULL,
  	customerId varchar2(40),
  	theme number(10,0) DEFAULT NULL,
  	groupId number(19,0),
  	openField1 clob,
  	openField2 clob,
  	openField3 clob,
  	openField4 clob,
  	openField5 clob,
	CONSTRAINT pk_basket PRIMARY KEY (id)
);

--
-- Table structure for table  'BasketOption' 
--

CREATE TABLE BasketOption (
  basket number(19,0) DEFAULT '0' NOT NULL,
  choice varchar2(4000),
  position number(10,0) DEFAULT '0' NOT NULL,
  CONSTRAINT pk_basket_option PRIMARY KEY (basket,position)
);

--
-- Table structure for table  'ClientIPRule' 
--

CREATE TABLE ClientIPRule (
  IPAddress varchar2(30) NOT NULL,
  SubnetMask varchar2(30) NOT NULL,
  Allow number(3,0) DEFAULT '0' NOT NULL,
  RuleID number(10,0) DEFAULT '0' NOT NULL,
  CONSTRAINT pk_client_ip_rule PRIMARY KEY (IPAddress,SubnetMask,Allow,RuleID)
);

-- 
-- Table structure for table  'Coupon' 
--

CREATE TABLE Coupon (
  	id number(19,0) NOT NULL,
  	typeId number(19,0) NOT NULL,
  	code varchar2(255) NOT NULL,
  	generated date NOT NULL,
  	given number(3,0) NOT NULL,
  	givenTo varchar2(255),
  	groupId number(19,0) NOT NULL,
  	name varchar2(255) NOT NULL,
  	priceRangeMin decimal(12, 2),
  	priceRangeMax decimal(12, 2),
  	priceRule varchar2(100) NOT NULL,
  	productCodes varchar2(4000),
  	itemCode varchar2(50),
  	sumAfterActivate decimal(12, 2),
  	used date,
  	usedCount number(10,0) NOT NULL,
  	validUntil date,
  	CONSTRAINT pk_coupon PRIMARY KEY (id)
);

-- 
-- Table structure for table  'CouponGroup' 
--

CREATE TABLE CouponGroup (
  	id number(19,0) NOT NULL,
  	title varchar2(255) NOT NULL,
  	CONSTRAINT pk_coupon_group PRIMARY KEY (id)
);

--
-- Table structure for table 'DatabaseVersion'
--

CREATE TABLE DatabaseVersion (
	version number(19,0) NOT NULL,
	CONSTRAINT pk_database_version PRIMARY KEY (version)
);

--
-- Table structure for table  'ELogi' 
--

CREATE TABLE ELogi (
  ID number(19,0) DEFAULT '0' NOT NULL,
  Status number(5,0) DEFAULT '0' NOT NULL,
  orderId number(19,0) NOT NULL,
  CONSTRAINT pk_elogi PRIMARY KEY (ID)
);


--
-- Table structure for table 'IPRule'
--

CREATE TABLE IPRule (
  IPAddress varchar2(30) NOT NULL,
  SubnetMask varchar2(30) NOT NULL,
  Allow number(3,0) DEFAULT '0' NOT NULL,
  RuleID number(10,0) DEFAULT '0' NOT NULL,
  CONSTRAINT pk_ip_rule PRIMARY KEY (IPAddress,SubnetMask,Allow,RuleID)
);

--
-- Table structure for table 'MessageEvents'
--

CREATE TABLE MessageEvents (
  ID number(19,0) NOT NULL,
  KeyField varchar2(255) DEFAULT NULL,
  MessageTemplate number(19,0) DEFAULT NULL,
  CONSTRAINT pk_message_events PRIMARY KEY (ID)
);

--
-- Table structure for table 'MessageReceivers'
--

CREATE TABLE MessageReceivers (
  MessageID number(19,0) DEFAULT '0' NOT NULL,
  UserID varchar2(255) DEFAULT NULL 
);

--
-- Table structure for table 'MessageTemplate'
--

CREATE TABLE MessageTemplate (
  ID number(19,0) NOT NULL,
  Name varchar2(255) DEFAULT NULL,
  FromEmail varchar2(255) DEFAULT NULL,
  ReplyTo varchar2(255) DEFAULT NULL,
  ErrorsTo varchar2(255) DEFAULT NULL,
  ReturnPath varchar2(255) DEFAULT NULL,
  Subject varchar2(255) DEFAULT NULL,
  MessagePlain clob,
  MessageHtml clob,
  ToCustomer number(3,0),
  ToOther varchar2(255) DEFAULT NULL,
  AttachHtml number(3,0),
  AttachmentName varchar2(255) DEFAULT NULL,
  CONSTRAINT pk_message_template PRIMARY KEY (ID)
);


--
-- Table structure for table 'Options'
--

CREATE TABLE Options (
  ID number(19,0) NOT NULL,
  Name varchar2(200),
  Info clob,
  Value clob,
  CONSTRAINT pk_options PRIMARY KEY (ID)
);

--
-- Table structure for table 'OrderHistory'
--

CREATE TABLE OrderHistory (
  id number(19,0) NOT NULL,
  status number(19,0) DEFAULT NULL,
  creationTime  timestamp DEFAULT NULL,
  creator clob,
  creatorComment clob,
  orderId number(19,0) DEFAULT NULL,
  CONSTRAINT pk_order_history PRIMARY KEY (id)
);

--
-- Table structure for table 'OrderStatus'
--

CREATE TABLE OrderStatus (
  id number(19,0) NOT NULL,
  eventId varchar2(255),
  name varchar2(255),
  type number(10,0) DEFAULT NULL,
  CONSTRAINT pk_order_status PRIMARY KEY (id)
);

--
-- Table structure for table 'Ordr'
--

CREATE TABLE Ordr (
  id number(19,0) NOT NULL,
  customerId varchar2(40),
  paymentMethod varchar2(60),
  deliveryMethod varchar2(200),
  referenceNumber varchar2(255),
  total decimal(12, 2) DEFAULT NULL,
  deliveryCost decimal(12, 2) DEFAULT NULL,
  deliveryVat decimal(12, 2) DEFAULT NULL,
  paymentCost decimal(12, 2) DEFAULT NULL,
  paymentVat decimal(12, 2) DEFAULT NULL,
  interestCost decimal(12, 2) DEFAULT NULL,
  interestRate decimal(12, 2) DEFAULT NULL,
  creationTime  timestamp DEFAULT NULL,
  followUp clob,
  handlingStatus number(19,0) DEFAULT NULL,
  paymentStatus number(19,0) DEFAULT NULL,
  currPrimaryLabel clob,
  currSecondaryLabel clob,
  currPrimaryDecimals number(10,0) DEFAULT NULL,
  currSecondaryDecimals number(10,0) DEFAULT NULL,
  currRelation decimal(12, 2) DEFAULT NULL,
  currClientFormat number(10,0) DEFAULT NULL,
  currAdminFormat number(10,0) DEFAULT NULL,
  cancelled number(3,0) NOT NULL,
  currPrimaryCode varchar2(255) DEFAULT NULL,
  currSecondaryCode varchar2(255) DEFAULT NULL,
  currPrimarySeparator char(1) DEFAULT NULL,
  currSecondarySeparator char(1) DEFAULT NULL,
  paymentCode clob,
  deliveryCode clob,
  orderNumber number(19,0) NOT NULL,
  ipaddress varchar2(80),
  paymentTransaction number(19,0),
  CONSTRAINT pk_ordr PRIMARY KEY (id)
);

CREATE TABLE OrderNumberSequence (
  id number(19,0) NOT NULL,
  info varchar2(10),
  CONSTRAINT pk_order_number_seq PRIMARY KEY (id)
);

--
-- Table structure for table 'Payment'
--

CREATE TABLE Payment (
  id number(19,0) NOT NULL,
  paymentId varchar2(40),
  Name varchar2(255),
  Description clob,
  ClassName varchar2(60) NOT NULL,
  Cost decimal(12, 2) DEFAULT '0' NOT NULL,
  Active number(3,0) NOT NULL,
  PrivateKey clob,
  PublicKey clob,
  Position number(10,0) DEFAULT '0' NOT NULL,
  PaymentCode varchar2(40),
  Internal number(3,0) NOT NULL,
  External number(3,0) NOT NULL,
  vatCategoryId number(19,0) NOT NULL,
  CONSTRAINT pk_payment PRIMARY KEY (id)
);

--
-- Table structure for table 'PrinettiTemplate'
--

CREATE TABLE PrinettiTemplate (
  id number(19,0) NOT NULL,
  name varchar2(50) NOT NULL,
  CONSTRAINT pk_prinetti_template PRIMARY KEY (id)
);

--
-- Table structure for table 'PrinettiTemplateSetting'
--

CREATE TABLE PrinettiTemplateSetting (
  id number(19,0) NOT NULL,
  templateId number(19,0) NOT NULL,
  name varchar2(50) NOT NULL,
  value clob,
  CONSTRAINT pk_prinetti_template_setting PRIMARY KEY (id)
);

--
-- Table structure for table 'Product'
--

CREATE TABLE Product (
  id number(19,0) NOT NULL,
  settings number(19,0) DEFAULT NULL,
  itemCode varchar2(255) NOT NULL,
  name varchar2(255),
  price decimal(12, 2) DEFAULT NULL,
  weight decimal(12, 2) DEFAULT NULL,
  height decimal(12, 2) DEFAULT NULL,
  width decimal(12, 2) DEFAULT NULL,
  depth decimal(12, 2) DEFAULT NULL, 
  unitPrice decimal(12, 2) DEFAULT NULL,
  unitType varchar2(255),
  packetSize number(10,0) DEFAULT NULL,
  packetType varchar2(255),
  defaultAmount number(10,0) DEFAULT NULL,
  minAmount number(10,0) DEFAULT NULL,
  maxAmount number(10,0) DEFAULT NULL,
  created  timestamp DEFAULT NULL,
  lastModified  timestamp DEFAULT NULL,
  modifier clob,
  visible number(3,0) DEFAULT '1',
  supplierId clob,
  supplierName clob,
  supplierItemCode clob,
  manufacturerId clob,
  manufacturerName clob,
  manufacturerItemCode clob,
  title1 clob,
  title2 clob,
  title3 clob,
  title4 clob,
  slogan1 clob,
  slogan2 clob,
  slogan3 clob,
  slogan4 clob,
  textInfo1 clob,
  textInfo2 clob,
  textInfo3 clob,
  textInfo4 clob,
  picture1Upload clob,
  picture1ReferenceURL clob,
  picture1Alt clob,
  picture2Upload clob,
  picture2ReferenceURL clob,
  picture2Alt clob,
  picture3Upload clob,
  picture3ReferenceURL clob,
  picture3Alt clob,
  picture4Upload clob,
  picture4ReferenceURL clob,
  picture4Alt clob,
  picture5Upload clob,
  picture5ReferenceURL clob,
  picture5Alt clob,
  file1Upload clob,
  file1ReferenceURL clob,
  file1LinkText clob,
  file2Upload clob,
  file2ReferenceURL clob,
  file2LinkText clob,
  file3Upload clob,
  file3ReferenceURL clob,
  file3LinkText clob,
  file4Upload clob,
  file4ReferenceURL clob,
  file4LinkText clob,
  file5Upload clob,
  file5ReferenceURL clob,
  file5LinkText clob,
  priceGroupRule1 clob,
  priceGroupRule2 clob,
  priceGroupRule3 clob,
  priceGroupRule4 clob,
  priceGroupRule5 clob,
  priceGroupRule6 clob,
  priceGroupRule7 clob,
  priceGroupRule8 clob,
  priceGroupRule9 clob,
  priceGroupRule10 clob,
  openField1 clob,
  openField2 clob,
  openField3 clob,
  openField4 clob,
  openField5 clob,
  openField6 clob,
  openField7 clob,
  openField8 clob,
  openField9 clob,
  openField10 clob,
  openField11 clob,
  openField12 clob,
  openField13 clob,
  openField14 clob,
  openField15 clob,
  openField16 clob,
  openField17 clob,
  openField18 clob,
  openField19 clob,
  openField20 clob,
  alarmText clob,
  inventoryName clob,
  alarmLimit number(10,0) DEFAULT NULL,
  amount number(10,0) DEFAULT NULL,
  section clob,
  shelf clob,
  purchasePrice decimal(12, 2) DEFAULT NULL,
  amountFactor number(10,0) DEFAULT '0' NOT NULL,
  vatCategoryId number(19,0) NOT NULL,
  productType number(19,0),
  CONSTRAINT pk_product PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductFieldLabel'
--


CREATE TABLE ProductFieldLabel (
    productType NUMBER NOT NULL,
    field VARCHAR(255) NOT NULL,
    label VARCHAR(255),
    CONSTRAINT PK_PRODUCTFIELDLABEL PRIMARY KEY (productType, field)
);


--
-- Table structure for table 'ProductGroup'
--

CREATE TABLE ProductGroup (
  id number(19,0) NOT NULL,
  name varchar2(255),
  groupCode varchar2(255),
  visible number(3,0) DEFAULT '1',
  picture1Alt clob,
  picture1URL clob,
  picture1Upload clob,
  infoText clob,
  infoTextVisible number(3,0) DEFAULT '0',
  parent number(19,0) DEFAULT NULL,
  productAmount number(10,0) DEFAULT NULL,
  position number(10,0) DEFAULT NULL,
  CONSTRAINT pk_product_group PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductOption'
--

CREATE TABLE ProductOption (
  id number(19,0) NOT NULL,
  name clob,
  parentProduct number(19,0) DEFAULT '0' NOT NULL,
  position number(10,0) DEFAULT NULL,
  CONSTRAINT pk_product_option PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductOptionChoice'
--

CREATE TABLE ProductOptionChoice (
  id number(19,0) NOT NULL,
  parentOption number(19,0) DEFAULT '0' NOT NULL,
  priceChange clob,
  itemCodeChange varchar2(255),
  optionAmount number(10,0) DEFAULT NULL,
  value clob,
  position number(10,0) DEFAULT NULL,
  CONSTRAINT pk_product_option_choice PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductSettings'
--

CREATE TABLE ProductSettings (
  id number(19,0) NOT NULL,
  pricesContainVat number(3,0) DEFAULT '0' NOT NULL,
  commonPictureURL clob,
  commonFileURL clob,
  defaultPictureAlt clob,
  defaultPictureReferenceURL clob,
  defaultPictureUpload clob,
  stockRemovalPolicy number(10,0) DEFAULT '0' NOT NULL,
  stockReturnPolicy number(10,0) DEFAULT '0' NOT NULL,
  stockHidePolicy number(10,0) DEFAULT '0' NOT NULL,
  useAlarmTexts number(3,0) DEFAULT '0' NOT NULL,
  useAmountRestrictions number(3,0) DEFAULT '0' NOT NULL,
  keyForDirectLink clob,
  useOptionBasedVisibility number(3,0) DEFAULT '0' NOT NULL,
  useContractPricing number(3,0) DEFAULT '0' NOT NULL,
  productRoundingPolicy number(10,0) DEFAULT '0' NOT NULL,
  useScalingPicture1 number(10,0) NOT NULL,
  useScalingPicture2 number(10,0) NOT NULL,
  useScalingPicture3 number(10,0) NOT NULL,
  useScalingPicture4 number(10,0) NOT NULL,
  useScalingPicture5 number(10,0) NOT NULL,
  thumbnailHeightPicture1 number(10,0) NOT NULL,
  thumbnailHeightPicture2 number(10,0) NOT NULL,
  thumbnailHeightPicture3 number(10,0) NOT NULL,
  thumbnailHeightPicture4 number(10,0) NOT NULL,
  thumbnailHeightPicture5 number(10,0) NOT NULL,
  thumbnailWidthPicture1 number(10,0) NOT NULL,
  thumbnailWidthPicture2 number(10,0) NOT NULL,
  thumbnailWidthPicture3 number(10,0) NOT NULL,
  thumbnailWidthPicture4 number(10,0) NOT NULL,
  thumbnailWidthPicture5 number(10,0) NOT NULL,
  CONSTRAINT pk_product_settings PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductSettingsSearchedProps'
--

CREATE TABLE ProductSettingsSearchedProps (
  ProductSettingsId number(19,0) DEFAULT '0' NOT NULL,
  property clob
);

--
-- Table structure for table 'ProductType'
--

CREATE TABLE ProductType (
    id NUMBER NOT NULL,
    code VARCHAR(40) NOT NULL,
    name VARCHAR(255),
    viewConfiguration CLOB,
    CONSTRAINT PK_PRODUCTTYPE PRIMARY KEY (id)
);


--
-- Table structure for table 'QuantityPricingRule'
--
 
CREATE TABLE QuantityPricingRule (
  id number(19,0) NOT NULL,
  threshold number(10,0) DEFAULT NULL,
  priceRule varchar2(255) DEFAULT NULL,
  parentProduct number(19,0) NOT NULL,
  position number(10,0) DEFAULT NULL,
  CONSTRAINT pk_quantity_pricing_rule PRIMARY KEY (id)
);

--
-- Table structure for table 'Settings'
--

CREATE TABLE Settings (
  ID number(19,0) NOT NULL,
  Name varchar2(200),
  Info clob,
  Value clob,
  Theme number(5,0) DEFAULT '0' NOT NULL,
  CONSTRAINT pk_settings PRIMARY KEY (ID)
);

--
-- Table structure for table 'Shopdata'
--

CREATE TABLE Shopdata (
  ID number(19,0) NOT NULL,
  FirmID number(10,0) DEFAULT '0' NOT NULL,
  Name varchar2(100),
  LYCode varchar2(40),
  Address varchar2(120),
  Email1 varchar2(120),
  Email2 varchar2(120),
  LogoURL varchar2(120),
  Email4 varchar2(120),
  Puh1 varchar2(40),
  Puh2 varchar2(40),
  Fax1 varchar2(40),
  Fax2 varchar2(40),
  Sale varchar2(40),
  Employees number(10,0) DEFAULT '0' NOT NULL,
  PostalCode varchar2(20),
  PostOffice varchar2(60),
  Field varchar2(120),
  Account1 varchar2(120),
  Account2 varchar2(120),
  WWW varchar2(200),
  Country char(2),
  AddressSpecifier varchar2(120),
  City varchar2(100),
  Name2 varchar2(100),
  CONSTRAINT pk_shopdata PRIMARY KEY (ID)
);

--
-- Table structure for table 'Transport'
--

CREATE TABLE Transport (
  ID number(19,0) NOT NULL,
  Name varchar2(200) NOT NULL,
  Description varchar2(200),
  Cost decimal(12, 2) DEFAULT '0' NOT NULL,
  Active number(3,0) DEFAULT '0' NOT NULL,
  Parameters clob,
  Code varchar2(20),
  Internal number(3,0) DEFAULT '1' NOT NULL,
  External number(3,0) DEFAULT '1' NOT NULL,
  Position number(10,0) DEFAULT '1'NOT NULL,
  vatCategoryId number(19,0) DEFAULT '0' NOT NULL,
  CONSTRAINT pk_transport PRIMARY KEY (ID)
);

--
-- Table structure for table 'CostCalculator'
--

CREATE TABLE CostCalculator (
	id number(19,0) NOT NULL, 
	typeId number(19,0) NOT NULL,
	parentId number(19,0),
	listIndex number(19,0) DEFAULT '0',
	CONSTRAINT pk_cost_calculator PRIMARY KEY (id)
);

--
-- Table structure for table 'CostCalculatorRule'
--
				 		
CREATE TABLE CostCalculatorRule (
	id number(19,0) NOT NULL,
	typeId number(19,0) NOT NULL,
	calculatorId number(19,0),
	listIndex number(19,0) DEFAULT '0',
	matchCondition decimal(12, 2) NOT NULL,
	priceRule varchar2(255),
	CONSTRAINT pk_cost_calculator_rule PRIMARY KEY (id)
);

--
-- Table structure for table 'Versions'
--

CREATE TABLE Version (
  id number(19,0),
  build number(19,0) DEFAULT '0' NOT NULL,
  version varchar2(20),
  time timestamp(0)  DEFAULT SYSDATE NOT NULL,
  product varchar2(20),
  CONSTRAINT pk_version PRIMARY KEY (id)
);


--
-- Table structure for table 'PaymentTransaction'
--

CREATE TABLE PaymentTransaction (
  id number(19,0) NOT NULL,
  orderId varchar2(255) DEFAULT NULL,
  callerId varchar2(255) DEFAULT NULL,
  reference varchar2(255) DEFAULT NULL,
  paymentMethod varchar2(255) DEFAULT NULL,
  currencyLabel varchar2(255) DEFAULT NULL,
  returnUrl varchar2(255) DEFAULT NULL,
  firstName varchar2(255) DEFAULT NULL,
  lastName varchar2(255) DEFAULT NULL,
  street varchar2(255) DEFAULT NULL,
  zipCode varchar2(255) DEFAULT NULL,
  city varchar2(255) DEFAULT NULL,
  state varchar2(255) DEFAULT NULL,
  countryCode varchar2(255) DEFAULT NULL,
  phone varchar2(255) DEFAULT NULL,
  email varchar2(255) DEFAULT NULL,
  time  timestamp DEFAULT NULL,
  status number(10,0) DEFAULT NULL,
  timedout number(3,0),
  language varchar2(25) DEFAULT NULL,
  CONSTRAINT pk_payment_transaction PRIMARY KEY (id)
);
 
--
-- Table structure for table 'PaymentTransactionItem'
--
 
CREATE TABLE PaymentTransactionItem (
  id number(19,0) NOT NULL,
  code varchar2(255) DEFAULT NULL,
  name varchar2(255) DEFAULT NULL,
  price decimal(12, 2) DEFAULT NULL,
  quantity number(10,0) DEFAULT NULL,
  transactionId number(19,0) DEFAULT NULL,
  position number(10,0) DEFAULT NULL,
  CONSTRAINT pk_payment_transaction_item PRIMARY KEY (id)
);

--
-- Table structure for table 'PaymentTransactionHistory'
--
 
CREATE TABLE PaymentTransactionHistory (
  id number(19,0) NOT NULL,
  time  timestamp DEFAULT NULL,
  type number(10,0) DEFAULT NULL,
  details clob DEFAULT NULL,
  transactionId number(19,0) DEFAULT NULL,
  position number(10,0) DEFAULT NULL,
  transactionStatus number(10,0) DEFAULT NULL,
  CONSTRAINT pk_payment_t_history PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductGroupAssociation'
--

CREATE TABLE ProductGroupAssociation (
   id number(19,0) NOT NULL,
   pid number(19,0) DEFAULT NULL,
   gid number(19,0) DEFAULT NULL,
   position number(10,0) DEFAULT NULL,
   CONSTRAINT pk_product_group_association PRIMARY KEY (id)
);

-- 
-- Table structure for table 'PricingContract'
--

CREATE TABLE PricingContract (
  id number(19,0) NOT NULL,
  itemCode varchar2(255),
  customerId varchar2(255),
  pricingContractGroup varchar2(255),
  customerGroupId varchar2(255),
  priceRule varchar2(255),
  CONSTRAINT pk_pricing_contract PRIMARY KEY (id)
);

--
-- Table structure for table 'PaymentParameters'
--

CREATE TABLE PaymentParameters (
  paymentId number(19,0) NOT NULL,
  Name varchar2(40) DEFAULT NULL,
  Value clob DEFAULT NULL,
  CONSTRAINT pk_payment_parameters PRIMARY KEY (paymentId,Name)
);

--
-- Table structure for table 'Identification'
--

CREATE TABLE Identification (
  id number(19,0) NOT NULL,
  code varchar2(20) NOT NULL,
  name clob,
  description clob,
  active number(3,0) DEFAULT '0' NOT NULL,
  CONSTRAINT pk_identification PRIMARY KEY (id) 
);

--
-- Table structure for table 'IdentificationTransaction'
--

CREATE TABLE IdentificationTransaction (
  id number(19,0) NOT NULL,
  callerId varchar2(255) DEFAULT NULL,
  time  timestamp DEFAULT NULL,
  identificationMethod varchar2(255) DEFAULT NULL,
  returnUrl clob,
  status number(10,0) DEFAULT NULL,
  CONSTRAINT pk_identification_transaction PRIMARY KEY (id)
);

--
-- Table structure for table 'IdentificationParameters'
--

CREATE TABLE IdentificationParameters (
  id number(19,0) NOT NULL,
  method number(19,0) DEFAULT '0' NOT NULL,
  name varchar2(30) NOT NULL,
  value clob NOT NULL,
  CONSTRAINT pk_identification_parameters PRIMARY KEY (id) 
);

--
-- Table structure for table 'IdentificationHistory'
--

CREATE TABLE IdentificationHistory (
  id number(19,0) NOT NULL,
  time timestamp DEFAULT NULL,
  type number(10,0) DEFAULT NULL,
  details clob,
  identificationStatus number(10,0) DEFAULT NULL,
  transactionId number(19,0) DEFAULT NULL,
  position number(10,0) DEFAULT NULL,
  CONSTRAINT pk_identification_history PRIMARY KEY (id)
);

--
-- Table structure for table 'PaymentTransactionProperty'
--

CREATE TABLE PaymentTransactionProperty (
  transactionId number(19,0) DEFAULT '0' NOT NULL,
  value varchar2(255) DEFAULT NULL,
  name varchar2(255) NOT NULL,
  CONSTRAINT pk_payment_t_property PRIMARY KEY (transactionId,name)
);


--
-- Table structure for table `GLAbstractRec`
--

CREATE TABLE GLAbstractRec (
	id number(19,0) NOT NULL,
	typeId number(19,0) NOT NULL,
	email  varchar2(150) NOT NULL,
 	csvVars clob,
 	customerId number(19,0),
 	emailMessageId number(19,0),
 	listIndex number(19,0),
	emailSourceContainerId number(19,0),
	cSRContainerId number(19,0),
	oSRContainerId number(19,0),
	orderId number(19,0),
	CONSTRAINT pk_gl_abstract_rec PRIMARY KEY (id)
 	);


--
-- Table structure for table `GLAbstractRestr`
--

CREATE TABLE GLAbstractRestr(
	id number(19,0) NOT NULL,
	typeId number(19,0),  
	blacklistId number(19,0),
	email  varchar2(150) NOT NULL,
	containerId number(19,0),
	CONSTRAINT pk_gl_abstract_restr PRIMARY KEY (id)
	);

 
--
-- Table structure for table `GLEmailSource`
--
CREATE TABLE GLEmailSource (
	 id number(19,0) NOT NULL, 
	 typeId number(19,0) NOT NULL, 
	 name  varchar2(150) NOT NULL,
	 sourceContainerId number(19,0),  
 	 restrictionContainerId number(19,0),  
	 errors number(19,0),
	 created timestamp(0) DEFAULT SYSDATE NOT NULL,
	 CONSTRAINT pk_gl_email_source PRIMARY KEY (id)
	 );
 
--
-- Table structure for table `GLSourceContainer`
--

CREATE TABLE GLSourceContainer(
	id number(19,0) NOT NULL,
	selectedGroups number(19,0),  
	blacklistOn number(3,0), 
	customerCheckOn number(3,0), 
	creationTimestamp number(19,0),
	additionalRestrictionsId number(19,0), 
	additionalEmailsId number(19,0),
    userId number(19,0) NOT NULL,
	CONSTRAINT pk_gl_source_container PRIMARY KEY (id)
	);
	
--
-- Table structure for table `GLCustomerGroup`
--

CREATE TABLE GLCustomerGroup(
	customerGroup number(19,0), 
	containerId number(19,0)
	);

--
-- Table structure for table `GLMailingList`
--

CREATE TABLE GLMailingList(
	id number(19,0) NOT NULL,
	containerId number(19,0) NOT NULL,
	emailFrom varchar2(150),
	emailReplyTo varchar2(150),
	emailReturnPath varchar2(150),
	emailErrorsTo varchar2(150),
	subject varchar2(255),
	message clob,
	htmlMessage clob,
	attachmentName varchar2(100),
	locked number(3,0),
	startTime timestamp,
	total number(19,0),
	successCounter number(19,0),
	errorCounter number(19,0),
    CONSTRAINT pk_gl_mailing_list PRIMARY KEY (id) 
	);


--
-- Table structure for table `GLEmailMessage`
--
	
CREATE TABLE GLEmailMessage(
	id number(19,0) NOT NULL,
 	mailQueueId number(19,0),
 	sent number(3,0) NOT NULL,
 	email varchar2(150) NOT NULL,
 	CONSTRAINT pk_gl_email_message PRIMARY KEY (id) 
 	);

--
-- Table structure for table 'GLProductBlock'
--

CREATE TABLE GLProductBlock (
	id number(19,0) NOT NULL,
	mailingListId number(19,0) NOT NULL,
	listIndex number(19,0) NOT NULL,
	CONSTRAINT pk_gl_product_block PRIMARY KEY (id)
	);

--
-- Table structure for table 'GLProduct'
--

create table GLProduct(
	productId number(19,0) not null, 
	productBlockId number(19,0) NOT NULL
	);
		
create table StatGroupVisit (ID number(19,0) not null, Created timestamp, WeekOfYear number(10,0), DayOfMonth number(10,0), DayOfWeek number(10,0), HourOfDay number(10,0), GroupPath varchar2(255), CONSTRAINT pk_stat_group_visit PRIMARY KEY (ID));
create table StatOrder (ID number(19,0) not null, modified timestamp, WeekOfYear number(10,0), DayOfMonth number(10,0), DayOfWeek number(10,0), HourOfDay number(10,0), GroupPath varchar2(255), ProductName varchar2(255), Quantity number(10,0), Sum float, OrderId number(10,0), CONSTRAINT pk_stat_order PRIMARY KEY (ID));
create table StatVisit (ID number(19,0) not null, Created timestamp, WeekOfYear number(10,0), DayOfMonth number(10,0), DayOfWeek number(10,0), HourOfDay number(10,0), Referer varchar2(255), CONSTRAINT pk_stat_visit PRIMARY KEY (ID));

CREATE TABLE PluginOption (
  id number(19,0) NOT NULL,
  name varchar2(200) NOT NULL,
  description varchar2(200),
  value clob,
  CONSTRAINT pk_plugin_option PRIMARY KEY (id) 
);

CREATE TABLE AccountCookie (
	id number(19,0) NOT NULL,
	customerId number(19,0),
	cookie varchar2(100) NOT NULL,
	listIndex number(19,0),
	CONSTRAINT pk_account_cookie PRIMARY KEY (id)
);
