-- PostgreSQL dump 1.0
--
-- Host: localhost    Database: organization
-- ------------------------------------------------------
-- Server version 8.2.4

--
-- LiquiBase
--

CREATE TABLE DATABASECHANGELOG (
  ID varchar(63) NOT NULL,
  AUTHOR varchar(63) NOT NULL,
  FILENAME varchar(200) NOT NULL,
  DATEEXECUTED timestamp NOT NULL,
  MD5SUM varchar(32) DEFAULT NULL,
  DESCRIPTION varchar(255) DEFAULT NULL,
  COMMENTS varchar(255) DEFAULT NULL,
  TAG varchar(255) DEFAULT NULL,
  LIQUIBASE varchar(10) DEFAULT NULL,
  CONSTRAINT pk_DATABASECHANGELOG PRIMARY KEY (ID,AUTHOR,FILENAME)
);

CREATE TABLE DATABASECHANGELOGLOCK (
  ID bigint NOT NULL,
  LOCKED boolean NOT NULL,
  LOCKGRANTED timestamp DEFAULT NULL,
  LOCKEDBY varchar(255) DEFAULT NULL,
  CONSTRAINT pk_DATABASECHANGELOGLOCK PRIMARY KEY (ID)
);

--*******************************************************
-- System module
--*******************************************************
--
-- Table structure for table 'Users'
--

CREATE TABLE Users (
  ID bigserial NOT NULL,
  UserID varchar(40) NOT NULL,
  Name varchar(120),
  EMail varchar(80),
  GSM varchar(40),
  Password varchar(40) NOT NULL,
  CONSTRAINT pk_users PRIMARY KEY (ID)
);

--
-- Table structure for table  'UserRight' 
--

CREATE TABLE UserRight(
  userId bigint NOT NULL, 
  accessZone varchar(40) NOT NULL, 
  CONSTRAINT pk_user_right PRIMARY KEY (userId, accessZone)
);

--*********************
-- End of System module
--********************* 
--******************************************************* 
-- Visual module
--******************************************************* 

--
-- Table structure for table 'Theme'
--

CREATE TABLE Theme (
  id bigserial NOT NULL,
  name varchar(255) NOT NULL,
  priceGroup smallint,
  CONSTRAINT pk_theme PRIMARY KEY (id)
);

--
-- Table structure for table 'Page'
--

CREATE TABLE Page (
  id bigserial NOT NULL,
  themeId bigint NOT NULL,
  typeId bigint NOT NULL,
  name varchar(255) default NULL,
  content text,
  CONSTRAINT pk_page PRIMARY KEY (id)
);

--
-- Table structure for table  'Elements' 
--

CREATE TABLE Elements (
  ID serial NOT NULL,
  Position int NOT NULL DEFAULT '0',
  TypeID bigint,
  Html text,
  Style text,
  Structure text,
  Text text,
  Pictures text,
  CustomerData text,
  pageId bigint NOT NULL,
  Name varchar(255),
  CheckboxAnswers text,
  CONSTRAINT pk_elements PRIMARY KEY (ID)
);

--
-- Table structure for table 'ProductListTemplates'
--

CREATE TABLE ProductListTemplates (
  ElementID int NOT NULL,
  StartHTML text,
  ProductHTML text,
  EndHTML text,
  GroupingHTML text,
  GroupSize int NOT NULL DEFAULT '1',
  ProductPageLinkText varchar(200),
  AddButtonURL varchar(200),
  QuantityFieldSize int NOT NULL DEFAULT '5',
  ProductPromotionGroupID bigint,
  NameMaxLength int NOT NULL DEFAULT '0',
  NameLink boolean NOT NULL DEFAULT FALSE,
  UsePaging boolean NOT NULL DEFAULT FALSE,
  ProductsPerPage smallint NOT NULL DEFAULT '10',
  NextPageLinkText text,
  PrevPageLinkText text,
  SaveButton text,
  RestoreButton text,
  UpdateButton text,
  DeleteItemButton text,
  DeleteAllButton text,
  OrderStatusSelector bigint,
  PictureLink boolean NOT NULL DEFAULT FALSE,
  IdLink boolean NOT NULL DEFAULT FALSE,
  ErrorHTML text,
  PromotionCriteria varchar(3) NOT NULL DEFAULT '1',
  SearchQuery text,
  DescriptionMaxLength int NOT NULL DEFAULT '0',
  AddAllButton text,
  OrderButton text,
  AddItemButton text,
  UpdateItemButton text,
  AddToWishlistButton text,
  AddAllWishlistButton text,
  AddWishlistButtonURL text,
  CONSTRAINT pk_product_list_template PRIMARY KEY (ElementID)
);

--********************* 
-- End of Visual module
--********************* 
--******************************************************* 
-- Question module
--******************************************************* 

CREATE TABLE QuestionCollection (
	id bigserial NOT NULL,
	name varchar(64) NOT NULL,
	CONSTRAINT pk_question_collection PRIMARY KEY (id)
);

CREATE TABLE Question (
	id bigserial NOT NULL,
	clientMode varchar(16) NOT NULL,
	collectionId bigint,
	customerEnabled boolean NOT NULL,
	orderEnabled boolean NOT NULL,
	position int,
	required boolean NOT NULL,
	discriminatorType bigint NOT NULL,
	usedInMatchingEnabled boolean NOT NULL,
	typeId bigint NOT NULL,
	CONSTRAINT pk_question PRIMARY KEY (id)
);

create table QuestionValidator (
	id bigserial NOT NULL,
	discriminator varchar(64) NOT NULL,
	enabled boolean NOT NULL,
	maxLength int,
	minLength int,
	questionId bigint NOT NULL,
	whitelist text,
	CONSTRAINT pk_question_validator PRIMARY KEY (id)
);

CREATE TABLE QuestionVersion (
	id bigserial NOT NULL,
	label text NOT NULL,
	position int NOT NULL,
	questionId bigint NOT NULL,
	CONSTRAINT pk_question_version PRIMARY KEY (id)
);

CREATE TABLE QuestionSetting (
	id bigserial NOT NULL,
	name varchar(64) NOT NULL,
	questionVersionId bigint NOT NULL,
	value text,
	CONSTRAINT pk_question_setting PRIMARY KEY (id)
);

CREATE TABLE Answer (
	id bigserial NOT NULL,
	value text,
	customerId bigint,
	orderId bigint,
	position int NOT NULL,
	questionId bigint,
	questionVersionId bigint,
	typeId bigint NOT NULL,
	CONSTRAINT pk_answer PRIMARY KEY (id)
);

--*********************** 
-- End of Question module
--*********************** 
--************************************************************ 
-- Customer module
-- Dependencies: Question module, System module, Visual module
--************************************************************ 

CREATE TABLE CustomerGroup (
	id bigserial NOT NULL,
	name varchar(255) NOT NULL,
	priceGroup int,
	themeId bigint,
	CONSTRAINT pk_customer_group PRIMARY KEY (id)
);

CREATE TABLE Customer (
	id bigserial NOT NULL,
	averageProducts decimal NOT NULL,
	averageSum decimal NOT NULL,
	contactPersonId bigint,
	created timestamp NOT NULL,
	customerNumber varchar(40) NOT NULL,
	lastVisit timestamp,
	login varchar(100),
	password varchar(100),
	primaryGroupId bigint,
	timesVisited int NOT NULL,
	totalSum decimal NOT NULL,
	customerModified timestamp,
	adminModified timestamp,
	adminId bigint,
	CONSTRAINT pk_customer PRIMARY KEY (id)
);

CREATE TABLE CustomerCustomerGroup (
	customerId bigserial NOT NULL,
	groupId bigint NOT NULL,
	CONSTRAINT pk_c_c_group PRIMARY KEY (customerId, groupId)
);

CREATE TABLE CustomerComment (
	id bigserial NOT NULL,
	customerComment text NOT NULL,
	created date NOT NULL,
	creatorId bigint NOT NULL,
	customerId bigint NOT NULL,
	CONSTRAINT pk_customer_comment PRIMARY KEY (id)
);

CREATE TABLE Wishlist (
	id bigserial NOT NULL,
	customerId bigint NOT NULL,
	name varchar(50) NOT NULL,
	CONSTRAINT pk_wishlist PRIMARY KEY (id)
);

CREATE TABLE WishlistItem (
	id bigserial NOT NULL,
	wishlistId bigint NOT NULL,
	productItemCode text NOT NULL,
	quantity int NOT NULL,
	choices text,
	CONSTRAINT pk_wishlist_item PRIMARY KEY (id)
);

--***********************
-- End of Customer module
--*********************** 
--************************************
-- Product module (VAT-related tables)
--************************************

CREATE TABLE VatRegion (
	id bigserial NOT NULL,
	countryCodes text NOT NULL,
	name varchar(100) NOT NULL,
	CONSTRAINT pk_vat_region PRIMARY KEY (id)
);

CREATE TABLE VatCategory (
	id bigserial NOT NULL,
	defaultRegionId bigint NOT NULL,
	name varchar(100) NOT NULL,
	CONSTRAINT pk_vat_category PRIMARY KEY (id)
);

CREATE TABLE Vat (
	id bigserial NOT NULL,
	rate decimal NOT NULL,
	vatCategoryId bigint,
	vatRegionId bigint,
	CONSTRAINT pk_vat PRIMARY KEY (id)
);

--**********************
-- End of Product module
--**********************

--
-- Table structure for table  'Basket' 
--

CREATE TABLE Basket (
  id bigserial NOT NULL,
  itemCode text,
  productId bigint DEFAULT NULL,
  productName text,
  quantity int DEFAULT NULL,
  price decimal DEFAULT NULL,
  weight decimal DEFAULT NULL,
  vat decimal DEFAULT NULL,
  total decimal DEFAULT NULL,
  totalweight decimal DEFAULT NULL,
  sessionId varchar(64),
  orderId bigint DEFAULT NULL,
  customerId varchar(40),
  theme int DEFAULT NULL,
  groupId bigint,
  openField1 text,
  openField2 text,
  openField3 text,
  openField4 text,
  openField5 text,
  CONSTRAINT pk_basket PRIMARY KEY (id)
);

--
-- Table structure for table  'BasketOption' 
--

CREATE TABLE BasketOption (
  basket bigint NOT NULL DEFAULT '0',
  choice text,
  position int NOT NULL DEFAULT '0',
  CONSTRAINT pk_basket_option PRIMARY KEY (basket,position)
);

--
-- Table structure for table  'ClientIPRule' 
--

CREATE TABLE ClientIPRule (
  IPAddress varchar(30) NOT NULL,
  SubnetMask varchar(30) NOT NULL,
  Allow boolean NOT NULL DEFAULT FALSE,
  RuleID int NOT NULL DEFAULT '0',
  CONSTRAINT pk_client_ip_rule PRIMARY KEY (IPAddress,SubnetMask,Allow,RuleID)
);

-- 
-- Table structure for table  'Coupon' 
--

CREATE TABLE Coupon (
  	id bigserial NOT NULL,
  	typeId bigint NOT NULL,
  	code varchar(255) NOT NULL,
  	generated date NOT NULL,
  	given boolean NOT NULL,
  	givenTo varchar(255),
  	groupId bigint NOT NULL,
  	name varchar(255) NOT NULL,
  	priceRangeMin decimal,
  	priceRangeMax decimal,
  	priceRule varchar(100) NOT NULL,
  	productCodes text,
  	itemCode varchar(50),
  	sumAfterActivate decimal,
  	used date,
  	usedCount int NOT NULL,
  	validUntil date,
  	CONSTRAINT pk_coupon PRIMARY KEY (id)
);

-- 
-- Table structure for table  'CouponGroup' 
--

CREATE TABLE CouponGroup (
  	id bigserial NOT NULL,
  	title varchar(255) NOT NULL,
  	CONSTRAINT pk_coupon_group PRIMARY KEY (id)
);

--
-- Table structure for table 'DatabaseVersion'
--

CREATE TABLE DatabaseVersion (
	version bigint NOT NULL,
	CONSTRAINT pk_database_version PRIMARY KEY (version)
);

--
-- Table structure for table  'ELogi' 
--

CREATE TABLE ELogi (
  ID bigint NOT NULL DEFAULT '0',
  Status smallint NOT NULL DEFAULT '0',
  orderId bigint NOT NULL,
  CONSTRAINT pk_elogi PRIMARY KEY (ID)
);


--
-- Table structure for table 'IPRule'
--

CREATE TABLE IPRule (
  IPAddress varchar(30) NOT NULL,
  SubnetMask varchar(30) NOT NULL,
  Allow boolean NOT NULL DEFAULT FALSE,
  RuleID int NOT NULL DEFAULT '0',
  CONSTRAINT pk_ip_rule PRIMARY KEY (IPAddress,SubnetMask,Allow,RuleID)
);

--
-- Table structure for table 'MessageEvents'
--

CREATE TABLE MessageEvents (
  ID bigserial NOT NULL,
  KeyField varchar(255) DEFAULT NULL,
  MessageTemplate bigint DEFAULT NULL,
  CONSTRAINT pk_message_events PRIMARY KEY (ID)
);

--
-- Table structure for table 'MessageReceivers'
--

CREATE TABLE MessageReceivers (
  MessageID bigint NOT NULL DEFAULT '0',
  UserID varchar(255) DEFAULT NULL 
);

--
-- Table structure for table 'MessageTemplate'
--

CREATE TABLE MessageTemplate (
  ID bigserial NOT NULL,
  Name varchar(255) DEFAULT NULL,
  FromEmail varchar(255) DEFAULT NULL,
  ReplyTo varchar(255) DEFAULT NULL,
  ErrorsTo varchar(255) DEFAULT NULL,
  ReturnPath varchar(255) DEFAULT NULL,
  Subject varchar(255) DEFAULT NULL,
  MessagePlain text,
  MessageHtml text,
  ToCustomer boolean DEFAULT FALSE,
  ToOther varchar(255) DEFAULT NULL,
  AttachHtml boolean DEFAULT FALSE,
  AttachmentName varchar(255) DEFAULT NULL,
  CONSTRAINT pk_message_template PRIMARY KEY (ID)
);


--
-- Table structure for table 'Options'
--

CREATE TABLE Options (
  ID serial NOT NULL,
  Name varchar(200),
  Info text,
  Value text,
  CONSTRAINT pk_options PRIMARY KEY (ID)
);

--
-- Table structure for table 'OrderHistory'
--

CREATE TABLE OrderHistory (
  id bigserial NOT NULL,
  status bigint DEFAULT NULL,
  creationTime timestamp DEFAULT NULL,
  creator text,
  creatorComment text,
  orderId bigint DEFAULT NULL,
  CONSTRAINT pk_order_history PRIMARY KEY (id)
);

--
-- Table structure for table 'OrderStatus'
--

CREATE TABLE OrderStatus (
  id bigserial NOT NULL,
  eventId text,
  name text,
  type int DEFAULT NULL,
  CONSTRAINT pk_order_status PRIMARY KEY (id)
);

--
-- Table structure for table 'Ordr'
--

CREATE TABLE Ordr (
  id bigserial NOT NULL,
  customerId text,
  paymentMethod text,
  deliveryMethod text,
  referenceNumber text,
  total decimal DEFAULT NULL,
  deliveryCost decimal DEFAULT NULL,
  deliveryVat decimal DEFAULT NULL,
  paymentCost decimal DEFAULT NULL,
  paymentVat decimal DEFAULT NULL,
  interestCost decimal DEFAULT NULL,
  interestRate decimal DEFAULT NULL,
  creationTime timestamp DEFAULT NULL,
  followUp text,
  handlingStatus bigint DEFAULT NULL,
  paymentStatus bigint DEFAULT NULL,
  currPrimaryLabel text,
  currSecondaryLabel text,
  currPrimaryDecimals int DEFAULT NULL,
  currSecondaryDecimals int DEFAULT NULL,
  currRelation decimal DEFAULT NULL,
  currClientFormat int DEFAULT NULL,
  currAdminFormat int DEFAULT NULL,
  cancelled boolean NOT NULL DEFAULT FALSE,
  currPrimaryCode varchar(255) DEFAULT NULL,
  currSecondaryCode varchar(255) DEFAULT NULL,
  currPrimarySeparator char(1) DEFAULT NULL,
  currSecondarySeparator char(1) DEFAULT NULL,
  paymentCode text,
  deliveryCode text,
  orderNumber bigint NOT NULL,
  ipaddress varchar(80),
  paymentTransaction bigint,
  CONSTRAINT pk_ordr PRIMARY KEY (id)
);

CREATE TABLE OrderNumberSequence (
  id bigserial NOT NULL,
  info varchar(10),
  CONSTRAINT pk_order_number_seq PRIMARY KEY (id)
);

--
-- Table structure for table 'Payment'
--

CREATE TABLE Payment (
  id bigserial NOT NULL,
  paymentId varchar(40),
  Name varchar(255),
  Description text,
  ClassName varchar(60) NOT NULL,
  Cost decimal NOT NULL DEFAULT '0',
  Active boolean NOT NULL DEFAULT FALSE,
  PrivateKey text,
  PublicKey text,
  Position int NOT NULL DEFAULT '0',
  PaymentCode varchar(40),
  Internal boolean NOT NULL DEFAULT TRUE,
  External boolean NOT NULL DEFAULT TRUE,
  vatCategoryId bigint NOT NULL,
  CONSTRAINT pk_payment PRIMARY KEY (id)
);

--
-- Table structure for table 'PrinettiTemplate'
--

CREATE TABLE PrinettiTemplate (
  id bigserial NOT NULL,
  name varchar(50) NOT NULL,
  CONSTRAINT pk_prinetti_template PRIMARY KEY (id)
);

--
-- Table structure for table 'PrinettiTemplateSetting'
--

CREATE TABLE PrinettiTemplateSetting (
  id bigserial NOT NULL,
  templateId bigint NOT NULL,
  name varchar(50) NOT NULL,
  value text,
  CONSTRAINT pk_prinetti_template_setting PRIMARY KEY (id)
);

--
-- Table structure for table 'Product'
--

CREATE TABLE Product (
  id bigserial NOT NULL,
  settings bigint DEFAULT NULL,
  itemCode varchar(255) NOT NULL,
  name text,
  price decimal DEFAULT NULL,
  weight decimal DEFAULT NULL,
  height decimal DEFAULT NULL,
  width decimal DEFAULT NULL,
  depth decimal DEFAULT NULL, 
  unitPrice decimal DEFAULT NULL,
  unitType text,
  packetSize int DEFAULT NULL,
  packetType text,
  defaultAmount int DEFAULT NULL,
  minAmount int DEFAULT NULL,
  maxAmount int DEFAULT NULL,
  created  timestamp DEFAULT NULL,
  lastModified  timestamp DEFAULT NULL,
  modifier text,
  visible boolean DEFAULT TRUE,
  supplierId text,
  supplierName text,
  supplierItemCode text,
  manufacturerId text,
  manufacturerName text,
  manufacturerItemCode text,
  title1 text,
  title2 text,
  title3 text,
  title4 text,
  slogan1 text,
  slogan2 text,
  slogan3 text,
  slogan4 text,
  textInfo1 text,
  textInfo2 text,
  textInfo3 text,
  textInfo4 text,
  picture1Upload text,
  picture1ReferenceURL text,
  picture1Alt text,
  picture2Upload text,
  picture2ReferenceURL text,
  picture2Alt text,
  picture3Upload text,
  picture3ReferenceURL text,
  picture3Alt text,
  picture4Upload text,
  picture4ReferenceURL text,
  picture4Alt text,
  picture5Upload text,
  picture5ReferenceURL text,
  picture5Alt text,
  file1Upload text,
  file1ReferenceURL text,
  file1LinkText text,
  file2Upload text,
  file2ReferenceURL text,
  file2LinkText text,
  file3Upload text,
  file3ReferenceURL text,
  file3LinkText text,
  file4Upload text,
  file4ReferenceURL text,
  file4LinkText text,
  file5Upload text,
  file5ReferenceURL text,
  file5LinkText text,
  priceGroupRule1 text,
  priceGroupRule2 text,
  priceGroupRule3 text,
  priceGroupRule4 text,
  priceGroupRule5 text,
  priceGroupRule6 text,
  priceGroupRule7 text,
  priceGroupRule8 text,
  priceGroupRule9 text,
  priceGroupRule10 text,
  openField1 text,
  openField2 text,
  openField3 text,
  openField4 text,
  openField5 text,
  openField6 text,
  openField7 text,
  openField8 text,
  openField9 text,
  openField10 text,
  openField11 text,
  openField12 text,
  openField13 text,
  openField14 text,
  openField15 text,
  openField16 text,
  openField17 text,
  openField18 text,
  openField19 text,
  openField20 text,
  alarmText text,
  inventoryName text,
  alarmLimit int DEFAULT NULL,
  amount int DEFAULT NULL,
  section text,
  shelf text,
  purchasePrice decimal DEFAULT NULL,
  amountFactor int NOT NULL DEFAULT '0',
  vatCategoryId bigint NOT NULL,
  productType bigint,
  CONSTRAINT pk_product PRIMARY KEY (id)
);


--
-- Table structure for table 'ProductFieldLabel'
--


CREATE TABLE ProductFieldLabel (
    productType int8 NOT NULL,
    field VARCHAR(255) NOT NULL,
    label VARCHAR(255),
    CONSTRAINT PK_PRODUCTFIELDLABEL PRIMARY KEY (productType, field)
);


--
-- Table structure for table 'ProductGroup'
--

CREATE TABLE ProductGroup (
  id bigserial NOT NULL,
  name text,
  groupCode text,
  visible boolean DEFAULT TRUE,
  picture1Alt text,
  picture1URL text,
  picture1Upload text,
  infoText text,
  infoTextVisible boolean DEFAULT FALSE,
  parent bigint DEFAULT NULL,
  productAmount int DEFAULT NULL,
  position int DEFAULT NULL,
  CONSTRAINT pk_product_group PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductOption'
--

CREATE TABLE ProductOption (
  id bigserial NOT NULL,
  name text,
  parentProduct bigint NOT NULL DEFAULT '0',
  position int default NULL,
  CONSTRAINT pk_product_option PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductOptionChoice'
--

CREATE TABLE ProductOptionChoice (
  id bigserial NOT NULL,
  parentOption bigint NOT NULL DEFAULT '0',
  priceChange text,
  itemCodeChange text,
  optionAmount int DEFAULT NULL,
  value text,
  position int DEFAULT NULL,
  CONSTRAINT pk_product_option_choice PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductSettings'
--

CREATE TABLE ProductSettings (
  id bigint NOT NULL,
  pricesContainVat boolean NOT NULL DEFAULT FALSE,
  commonPictureURL text,
  commonFileURL text,
  defaultPictureAlt text,
  defaultPictureReferenceURL text,
  defaultPictureUpload text,
  stockRemovalPolicy int NOT NULL DEFAULT '0',
  stockReturnPolicy int NOT NULL DEFAULT '0',
  stockHidePolicy int NOT NULL DEFAULT '0',
  useAlarmTexts boolean NOT NULL DEFAULT FALSE,
  useAmountRestrictions boolean NOT NULL DEFAULT FALSE,
  keyForDirectLink text,
  useOptionBasedVisibility boolean NOT NULL DEFAULT FALSE,
  useContractPricing boolean NOT NULL DEFAULT FALSE,
  productRoundingPolicy int NOT NULL DEFAULT '0',
  useScalingPicture1 boolean NOT NULL default FALSE,
  useScalingPicture2 boolean NOT NULL default FALSE,
  useScalingPicture3 boolean NOT NULL default FALSE,
  useScalingPicture4 boolean NOT NULL default FALSE,
  useScalingPicture5 boolean NOT NULL default FALSE,
  thumbnailHeightPicture1 int NOT NULL default '0',
  thumbnailHeightPicture2 int NOT NULL default '0',
  thumbnailHeightPicture3 int NOT NULL default '0',
  thumbnailHeightPicture4 int NOT NULL default '0',
  thumbnailHeightPicture5 int NOT NULL default '0',
  thumbnailWidthPicture1 int NOT NULL default '0',
  thumbnailWidthPicture2 int NOT NULL default '0',
  thumbnailWidthPicture3 int NOT NULL default '0',
  thumbnailWidthPicture4 int NOT NULL default '0',
  thumbnailWidthPicture5 int NOT NULL default '0',
  CONSTRAINT pk_product_settings PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductSettingsSearchedProps'
--

CREATE TABLE ProductSettingsSearchedProps (
  ProductSettingsId bigint NOT NULL DEFAULT '0',
  property text
);

--
-- Table structure for table 'ProductType'
--

CREATE TABLE ProductType (
    id bigserial NOT NULL,
    code VARCHAR(40) NOT NULL,
    name VARCHAR(255),
    viewConfiguration TEXT,
    CONSTRAINT PK_PRODUCTTYPE PRIMARY KEY (id)
);

--
-- Table structure for table 'QuantityPricingRule'
--
 
CREATE TABLE QuantityPricingRule (
  id bigserial NOT NULL,
  threshold int DEFAULT NULL,
  priceRule varchar(255) DEFAULT NULL,
  parentProduct bigint NOT NULL,
  position int DEFAULT NULL,
  CONSTRAINT pk_quantity_pricing_rule PRIMARY KEY (id)
);

--
-- Table structure for table 'Settings'
--

CREATE TABLE Settings (
  ID serial NOT NULL,
  Name varchar(200),
  Info text,
  Value text,
  Theme smallint NOT NULL DEFAULT '0',
  CONSTRAINT pk_settings PRIMARY KEY (ID)
);

--
-- Table structure for table 'Shopdata'
--

CREATE TABLE Shopdata (
  ID serial NOT NULL,
  FirmID int NOT NULL DEFAULT '0',
  Name varchar(100),
  LYCode varchar(40),
  Address varchar(120),
  Email1 varchar(120),
  Email2 varchar(120),
  LogoURL varchar(120),
  Email4 varchar(120),
  Puh1 varchar(40),
  Puh2 varchar(40),
  Fax1 varchar(40),
  Fax2 varchar(40),
  Sale varchar(40),
  Employees int NOT NULL DEFAULT '0',
  PostalCode varchar(20),
  PostOffice varchar(60),
  Field varchar(120),
  Account1 varchar(120),
  Account2 varchar(120),
  WWW varchar(200),
  Country char(2),
  AddressSpecifier varchar(120),
  City varchar(100),
  Name2 varchar(100),
  CONSTRAINT pk_shopdata PRIMARY KEY (ID)
);

--
-- Table structure for table 'Transport'
--

CREATE TABLE Transport (
  ID serial NOT NULL,
  Name varchar(200) NOT NULL,
  Description varchar(200),
  Cost decimal NOT NULL DEFAULT '0',
  Active boolean NOT NULL DEFAULT FALSE,
  Parameters text,
  Code varchar(20),
  Internal boolean NOT NULL DEFAULT TRUE,
  External boolean NOT NULL DEFAULT TRUE,
  Position int NOT NULL DEFAULT '1',
  vatCategoryId bigint NOT NULL DEFAULT '0',
  CONSTRAINT pk_transport PRIMARY KEY (ID)
);

--
-- Table structure for table 'CostCalculator'
--

CREATE TABLE CostCalculator (
	id bigserial NOT NULL, 
	typeId bigint NOT NULL,
	parentId bigint,
	listIndex bigint DEFAULT '0',
	CONSTRAINT pk_cost_calculator PRIMARY KEY (id)
);

--
-- Table structure for table 'CostCalculatorRule'
--
				 		
CREATE TABLE CostCalculatorRule (
	id bigserial NOT NULL,
	typeId bigint NOT NULL,
	calculatorId bigint,
	listIndex bigint DEFAULT '0',
	matchCondition decimal NOT NULL,
	priceRule varchar(255),
	CONSTRAINT pk_cost_calculator_rule PRIMARY KEY (id)
);

--
-- Table structure for table 'Versions'
--

CREATE TABLE Version (
  id bigserial,
  build bigint NOT NULL DEFAULT '0',
  version varchar(20),
  time timestamp(0) NOT NULL DEFAULT NOW(),
  product varchar(20),
  CONSTRAINT pk_version PRIMARY KEY (id)
);


--
-- Table structure for table 'PaymentTransaction'
--

CREATE TABLE PaymentTransaction (
  id bigserial NOT NULL,
  orderId varchar(255) DEFAULT NULL,
  callerId varchar(255) DEFAULT NULL,
  reference varchar(255) DEFAULT NULL,
  paymentMethod varchar(255) DEFAULT NULL,
  currencyLabel varchar(255) DEFAULT NULL,
  returnUrl varchar(255) DEFAULT NULL,
  firstName varchar(255) DEFAULT NULL,
  lastName varchar(255) DEFAULT NULL,
  street varchar(255) DEFAULT NULL,
  zipCode varchar(255) DEFAULT NULL,
  city varchar(255) DEFAULT NULL,
  state varchar(255) DEFAULT NULL,
  countryCode varchar(255) DEFAULT NULL,
  phone varchar(255) DEFAULT NULL,
  email varchar(255) DEFAULT NULL,
  time  timestamp DEFAULT NULL,
  status int DEFAULT NULL,
  timedout boolean,
  language varchar(25) DEFAULT NULL,
  CONSTRAINT pk_payment_transaction PRIMARY KEY (id)
);
 
--
-- Table structure for table 'PaymentTransactionItem'
--
 
CREATE TABLE PaymentTransactionItem (
  id bigserial NOT NULL,
  code varchar(255) DEFAULT NULL,
  name varchar(255) DEFAULT NULL,
  price decimal DEFAULT NULL,
  quantity int DEFAULT NULL,
  transactionId bigint DEFAULT NULL,
  position int DEFAULT NULL,
  CONSTRAINT pk_payment_transaction_item PRIMARY KEY (id)
);

--
-- Table structure for table 'PaymentTransactionHistory'
--
 
CREATE TABLE PaymentTransactionHistory (
  id bigserial NOT NULL,
  time  timestamp DEFAULT NULL,
  type int DEFAULT NULL,
  details text DEFAULT NULL,
  transactionId bigint DEFAULT NULL,
  position int DEFAULT NULL,
  transactionStatus int DEFAULT NULL,
  CONSTRAINT pk_payment_t_history PRIMARY KEY (id)
);

--
-- Table structure for table 'ProductGroupAssociation'
--

CREATE TABLE ProductGroupAssociation (
   id bigserial NOT NULL,
   pid bigint DEFAULT NULL,
   gid bigint DEFAULT NULL,
   position int DEFAULT NULL,
   CONSTRAINT pk_product_group_association PRIMARY KEY (id)
);

-- 
-- Table structure for table 'PricingContract'
--

CREATE TABLE PricingContract (
  id bigserial NOT NULL,
  itemCode varchar(255),
  customerId varchar(255),
  pricingContractGroup varchar(255),
  customerGroupId varchar(255),
  priceRule varchar(255),
  CONSTRAINT pk_pricing_contract PRIMARY KEY (id)
);

--
-- Table structure for table 'PaymentParameters'
--

CREATE TABLE PaymentParameters (
  paymentId bigint NOT NULL,
  Name varchar(40) DEFAULT NULL,
  Value text DEFAULT NULL,
  CONSTRAINT pk_payment_parameters PRIMARY KEY (paymentId,Name)
);

--
-- Table structure for table 'Identification'
--

CREATE TABLE Identification (
  id bigserial NOT NULL,
  code varchar(20),
  name text,
  description text,
  active boolean NOT NULL DEFAULT FALSE,
  CONSTRAINT pk_identification PRIMARY KEY (id) 
);

--
-- Table structure for table 'IdentificationTransaction'
--

CREATE TABLE IdentificationTransaction (
  id bigserial NOT NULL,
  callerId varchar(255) DEFAULT NULL,
  time timestamp DEFAULT NULL,
  identificationMethod varchar(255) DEFAULT NULL,
  returnUrl text,
  status int DEFAULT NULL,
  CONSTRAINT pk_identification_transaction PRIMARY KEY (id)
);

--
-- Table structure for table 'IdentificationParameters'
--

CREATE TABLE IdentificationParameters (
  id bigserial NOT NULL,
  method bigint NOT NULL DEFAULT '0',
  name varchar(30) NOT NULL,
  value text NOT NULL,
  CONSTRAINT pk_identification_parameters PRIMARY KEY (id)
);

--
-- Table structure for table 'IdentificationHistory'
--

CREATE TABLE IdentificationHistory (
  id bigserial NOT NULL,
  time timestamp DEFAULT NULL,
  type int DEFAULT NULL,
  details text,
  identificationStatus int DEFAULT NULL,
  transactionId bigint DEFAULT NULL,
  position int DEFAULT NULL,
  CONSTRAINT pk_identification_history PRIMARY KEY (id)
);

--
-- Table structure for table 'PaymentTransactionProperty'
--

CREATE TABLE PaymentTransactionProperty (
  transactionId bigint NOT NULL DEFAULT '0',
  value varchar(255) DEFAULT NULL,
  name varchar(255),
  CONSTRAINT pk_payment_t_property PRIMARY KEY (transactionId,name)
);

--
-- Table structure for table `GLAbstractRec`
--

CREATE TABLE GLAbstractRec (
	id BIGSERIAL NOT NULL,
	typeId BIGINT NOT NULL,
	email  VARCHAR(150) NOT NULL,
 	csvVars TEXT,
 	customerId BIGINT,
 	emailMessageId BIGINT,
 	listIndex BIGINT,
	emailSourceContainerId BIGINT,
	cSRContainerId BIGINT,
	oSRContainerId BIGINT,
	orderId BIGINT,
	CONSTRAINT pk_gl_abstract_rec PRIMARY KEY (id)
 	);


--
-- Table structure for table `GLAbstractRestr`
--

CREATE TABLE GLAbstractRestr(
	id BIGSERIAL NOT NULL,
	typeId BIGINT,  
	blacklistId BIGINT,
	email  VARCHAR(150) NOT NULL,
	containerId BIGINT,
	CONSTRAINT pk_gl_abstract_restr PRIMARY KEY (id)
	);

 
--
-- Table structure for table `GLEmailSource`
--
CREATE TABLE GLEmailSource (
	 id BIGSERIAL NOT NULL, 
	 typeId BIGINT NOT NULL, 
	 name  VARCHAR(150) NOT NULL,
	 sourceContainerId BIGINT,  
 	 restrictionContainerId BIGINT,  
	 errors BIGINT,
	 created TIMESTAMP(0) NOT NULL DEFAULT NOW(),
	 CONSTRAINT pk_gl_email_source PRIMARY KEY (id)
	 );
 
--
-- Table structure for table `GLSourceContainer`
--

CREATE TABLE GLSourceContainer(
	id BIGSERIAL NOT NULL,
	selectedGroups BIGINT,  
	blacklistOn BOOLEAN, 
	customerCheckOn BOOLEAN, 
	creationTimestamp BIGINT,
	additionalRestrictionsId BIGINT, 
	additionalEmailsId BIGINT,
    userId BIGINT NOT NULL,
	CONSTRAINT pk_gl_source_container PRIMARY KEY (id)	
	);
--
-- Table structure for table `GLCustomerGroup`
--

CREATE TABLE GLCustomerGroup(
	customerGroup BIGINT, 
	containerId BIGINT
	);

--
-- Table structure for table `GLMailingList`
--

CREATE TABLE GLMailingList(
	id BIGSERIAL NOT NULL,
	containerId BIGINT NOT NULL,
	emailFrom VARCHAR(150),
	emailReplyTo VARCHAR(150),
	emailReturnPath VARCHAR(150),
	emailErrorsTo VARCHAR(150),
	subject VARCHAR(255),
	message TEXT,
	htmlMessage TEXT,
	attachmentName VARCHAR(100),
	locked BOOLEAN,
	startTime timestamp,
	total BIGINT,
	successCounter BIGINT,
	errorCounter BIGINT,
    CONSTRAINT pk_gl_mailing_list PRIMARY KEY (id)
	);


--
-- Table structure for table `GLEmailMessage`
--
	
CREATE TABLE GLEmailMessage(
	id BIGSERIAL NOT NULL,
 	mailQueueId BIGINT,
 	sent BOOLEAN NOT NULL,
 	email VARCHAR(150) NOT NULL,
 	CONSTRAINT pk_gl_email_message PRIMARY KEY (id)
 	);

--
-- Table structure for table 'GLProductBlock'
--

CREATE TABLE GLProductBlock (
	id BIGSERIAL NOT NULL,
	mailingListId bigint NOT NULL,
	listIndex bigint NOT NULL,
	CONSTRAINT pk_gl_product_block PRIMARY KEY (id)
	);

--
-- Table structure for table 'GLProduct'
--

create table GLProduct(
	productId bigint not null, 
	productBlockId bigint NOT NULL
	);
		
create table StatGroupVisit (ID serial not null, Created timestamp, WeekOfYear int4, DayOfMonth int4, DayOfWeek int4, HourOfDay int4, GroupPath varchar(255),  CONSTRAINT pk_statgroupvisit PRIMARY KEY (ID));
create table StatOrder (ID serial not null, modified timestamp, WeekOfYear int4, DayOfMonth int4, DayOfWeek int4, HourOfDay int4, GroupPath varchar(255), ProductName varchar(255), Quantity int4, Sum float8, OrderId int8, CONSTRAINT pk_statorder PRIMARY KEY (ID));
create table StatVisit (ID serial not null, Created timestamp, WeekOfYear int4, DayOfMonth int4, DayOfWeek int4, HourOfDay int4, Referer varchar(255), CONSTRAINT pk_statvisit PRIMARY KEY (ID));

CREATE TABLE PluginOption (
  id serial NOT NULL,
  name varchar(200) NOT NULL,
  description varchar(200),
  value text,
  CONSTRAINT pk_plugin_option PRIMARY KEY (id) 
);

CREATE TABLE AccountCookie (
	id bigserial NOT NULL,
	customerId bigint,
	cookie varchar(100) NOT NULL,
	listIndex bigint,
	CONSTRAINT pk_account_cookie PRIMARY KEY (id)
);
